OC.L10N.register(
    "gallery",
    {
    "Pictures" : "Images",
    "Picture view" : "Visualisation de l'image",
    "Next" : "Suivant",
    "Play" : "Démarrer",
    "Pause" : "Pause",
    "Previous" : "Précédent",
    "Close" : "Fermer",
    "Error loading slideshow template" : "Erreur lors du téléchargement du modèle de diaporama ",
    "Share" : "Partager",
    "No pictures found! If you upload pictures in the files app, they will be displayed here." : "Aucune image trouvée ! Si vous ajoutez des images dans l'application Fichiers, elles seront affichées ici.",
    "shared by %s" : "partagé par %s",
    "File list" : "Liste des fichiers"
},
"nplurals=2; plural=(n > 1);");
